Class: Aws::Ivschat::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Ivschat::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ivschat/client.rb,
sig/client.rbs
Overview
An API client for Ivschat. To construct a client, you need to configure a :region and :credentials.
client = Aws::Ivschat::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateChatTokenResponseSuccess, _CreateLoggingConfigurationResponseSuccess, _CreateRoomResponseSuccess, _DeleteMessageResponseSuccess, _DisconnectUserResponseSuccess, _GetLoggingConfigurationResponseSuccess, _GetRoomResponseSuccess, _ListLoggingConfigurationsResponseSuccess, _ListRoomsResponseSuccess, _ListTagsForResourceResponseSuccess, _SendEventResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateLoggingConfigurationResponseSuccess, _UpdateRoomResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_chat_token(params = {}) ⇒ Types::CreateChatTokenResponse
Creates an encrypted token that is used by a chat participant to establish an individual WebSocket chat connection to a room.
-
#create_logging_configuration(params = {}) ⇒ Types::CreateLoggingConfigurationResponse
Creates a logging configuration that allows clients to store and record sent messages.
-
#create_room(params = {}) ⇒ Types::CreateRoomResponse
Creates a room that allows clients to connect and pass messages.
-
#delete_logging_configuration(params = {}) ⇒ Struct
Deletes the specified logging configuration.
-
#delete_message(params = {}) ⇒ Types::DeleteMessageResponse
Sends an event to a specific room which directs clients to delete a specific message; that is, unrender it from view and delete it from the client’s chat history.
-
#delete_room(params = {}) ⇒ Struct
Deletes the specified room.
-
#disconnect_user(params = {}) ⇒ Struct
Disconnects all connections using a specified user ID from a room.
-
#get_logging_configuration(params = {}) ⇒ Types::GetLoggingConfigurationResponse
Gets the specified logging configuration.
-
#get_room(params = {}) ⇒ Types::GetRoomResponse
Gets the specified room.
-
#list_logging_configurations(params = {}) ⇒ Types::ListLoggingConfigurationsResponse
Gets summary information about all your logging configurations in the AWS region where the API request is processed.
-
#list_rooms(params = {}) ⇒ Types::ListRoomsResponse
Gets summary information about all your rooms in the AWS region where the API request is processed.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets information about AWS tags for the specified ARN.
-
#send_event(params = {}) ⇒ Types::SendEventResponse
Sends an event to a room.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for the AWS resource with the specified ARN.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource with the specified ARN.
-
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Updates a specified logging configuration.
-
#update_room(params = {}) ⇒ Types::UpdateRoomResponse
Updates a room’s configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ivschat/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1369 1370 1371 |
# File 'lib/aws-sdk-ivschat/client.rb', line 1369 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1372 1373 1374 |
# File 'lib/aws-sdk-ivschat/client.rb', line 1372 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/aws-sdk-ivschat/client.rb', line 1342 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Ivschat') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ivschat' context[:gem_version] = '1.62.0' Seahorse::Client::Request.new(handlers, context) end |
#create_chat_token(params = {}) ⇒ Types::CreateChatTokenResponse
Creates an encrypted token that is used by a chat participant to establish an individual WebSocket chat connection to a room. When the token is used to connect to chat, the connection is valid for the session duration specified in the request. The token becomes invalid at the token-expiration timestamp included in the response.
Use the capabilities field to permit an end user to send messages or
moderate a room.
The attributes field securely attaches structured data to the chat
session; the data is included within each message sent by the end user
and received by other participants in the room. Common use cases for
attributes include passing end-user profile data like an icon, display
name, colors, badges, and other display features.
Encryption keys are owned by Amazon IVS Chat and never used directly by your application.
88 |
# File 'sig/client.rbs', line 88
def create_chat_token: (
|
#create_logging_configuration(params = {}) ⇒ Types::CreateLoggingConfigurationResponse
Creates a logging configuration that allows clients to store and record sent messages.
109 |
# File 'sig/client.rbs', line 109
def create_logging_configuration: (
|
#create_room(params = {}) ⇒ Types::CreateRoomResponse
Creates a room that allows clients to connect and pass messages.
130 |
# File 'sig/client.rbs', line 130
def create_room: (
|
#delete_logging_configuration(params = {}) ⇒ Struct
Deletes the specified logging configuration.
144 |
# File 'sig/client.rbs', line 144
def delete_logging_configuration: (
|
#delete_message(params = {}) ⇒ Types::DeleteMessageResponse
Sends an event to a specific room which directs clients to delete a
specific message; that is, unrender it from view and delete it from
the client’s chat history. This event’s EventName is
aws:DELETE_MESSAGE. This replicates the DeleteMessage
WebSocket operation in the Amazon IVS Chat Messaging API.
154 |
# File 'sig/client.rbs', line 154
def delete_message: (
|
#delete_room(params = {}) ⇒ Struct
Deletes the specified room.
162 |
# File 'sig/client.rbs', line 162
def delete_room: (
|
#disconnect_user(params = {}) ⇒ Struct
Disconnects all connections using a specified user ID from a room. This replicates the DisconnectUser WebSocket operation in the Amazon IVS Chat Messaging API.
171 |
# File 'sig/client.rbs', line 171
def disconnect_user: (
|
#get_logging_configuration(params = {}) ⇒ Types::GetLoggingConfigurationResponse
Gets the specified logging configuration.
190 |
# File 'sig/client.rbs', line 190
def get_logging_configuration: (
|
#get_room(params = {}) ⇒ Types::GetRoomResponse
Gets the specified room.
209 |
# File 'sig/client.rbs', line 209
def get_room: (
|
#list_logging_configurations(params = {}) ⇒ Types::ListLoggingConfigurationsResponse
Gets summary information about all your logging configurations in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
220 |
# File 'sig/client.rbs', line 220
def list_logging_configurations: (
|
#list_rooms(params = {}) ⇒ Types::ListRoomsResponse
Gets summary information about all your rooms in the AWS region where
the API request is processed. Results are sorted in descending order
of updateTime.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
232 |
# File 'sig/client.rbs', line 232
def list_rooms: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets information about AWS tags for the specified ARN.
246 |
# File 'sig/client.rbs', line 246
def list_tags_for_resource: (
|
#send_event(params = {}) ⇒ Types::SendEventResponse
Sends an event to a room. Use this within your application’s business logic to send events to clients of a room; e.g., to notify clients to change the way the chat UI is rendered.
256 |
# File 'sig/client.rbs', line 256
def send_event: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for the AWS resource with the specified ARN.
267 |
# File 'sig/client.rbs', line 267
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource with the specified ARN.
277 |
# File 'sig/client.rbs', line 277
def untag_resource: (
|
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Updates a specified logging configuration.
295 |
# File 'sig/client.rbs', line 295
def update_logging_configuration: (
|
#update_room(params = {}) ⇒ Types::UpdateRoomResponse
Updates a room’s configuration.
316 |
# File 'sig/client.rbs', line 316
def update_room: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1362 1363 1364 |
# File 'lib/aws-sdk-ivschat/client.rb', line 1362 def waiter_names [] end |